@@ -287,7 +287,9 @@ def transmit_context(visorfile, archive, server_url=None):
         'post',
         'transmit',
         json={
-          'chunks': { x: base64.b64encode(chunks[x]) for x in missing_chunks }
+          'chunks': {
+            x: base64.b64encode(chunks[x]).decode('ascii') for x in missing_chunks
+          }
         }
       )
   return filemap
